@@ -2,7 +2,7 @@ from enum import Enum, unique
 
 from . import geo
 
-__version__ = '0.1.3'
+__version__ = '0.1.4'
 
 @unique
 class LineCap(Enum):
@@ -22,13 +22,17 @@ class DashPattern (Enum):
     Dot = 1
     SparseDash = 2
     DashDot = 3
+    DenseDot = 4
+    SparseDot = 5
 
 def _DashPatternToArray (p):
     m = {
         DashPattern.Dash: [5, 5],
-        DashPattern.Dot: [1, 5],
+        DashPattern.Dot: [0, 3],
         DashPattern.SparseDash: [5, 10],
-        DashPattern.DashDot: [15, 10, 5, 10]
+        DashPattern.DashDot: [15, 10, 0, 10],
+        DashPattern.DenseDot: [0, 1.5],
+        DashPattern.SparseDot: [0, 5]
     }
 
     return m [p]
@@ -286,7 +290,7 @@ class Group (Element):
     def __init__(self, translation=(0, 0), name=None):
         super(Group, self).__init__ ()
         self._name = name
-        self._translation = translation
+        self._translation = geo.Vector2 (translation)
 
     def Add (self, item):
         self._children.append (item)
@@ -403,7 +407,7 @@ class Drawing (Element):
         size = geo.Vector2 (0, 0)
 
         if self._width is None or self._height is None:
-            size = self.GetBounds ().GetSize ()
+            size = self.GetBounds ().GetMaximum ()
 
         if self._width is not None:
             size [0] = self._width
